<?php
// Evita el acceso directo.
if (!defined('ABSPATH')) exit;

// Añade los scripts necesarios para la página de administración.
function gcd_admin_enqueue_scripts($hook) {
    if ($hook != 'toplevel_page_gcd-admin') {
        return;
    }

    // Encolar jQuery, que WordPress ya tiene.
    wp_enqueue_script('jquery');

    // Encolar el script de administración personalizado.
    wp_enqueue_script('gcd-admin-script', plugin_dir_url(__FILE__) . 'admin-script.js', array('jquery'), '1.0', true);

    // Pasar la URL de AJAX a nuestro script.
    wp_localize_script('gcd-admin-script', 'gcd_ajax', array('ajax_url' => admin_url('admin-ajax.php')));
}
add_action('admin_enqueue_scripts', 'gcd_admin_enqueue_scripts');

// Función para crear la página de administración.
function gcd_admin_menu() {
    add_menu_page('Códigos de Descuento', 'Códigos de Descuento', 'manage_options', 'gcd-admin', 'gcd_admin_page');
}
add_action('admin_menu', 'gcd_admin_menu');

// Contenido de la página de administración.
function gcd_admin_page() {
    $codes = get_option('gcd_codes', array());
    ?>
    <div class="wrap">
    <h1>Configuración del Generador de Códigos de Descuento</h1>
    <p>Este plugin genera códigos de descuento aleatorios de 6 letras y 4 números. Puedes generar un código usando el botón en el frontend mediante el shortcode proporcionado.</p>

    <h2>Uso del Shortcode</h2>
    <p>Inserta el siguiente shortcode donde quieras mostrar el botón de generación de códigos:</p>
    <input type="text" id="gcd-shortcode" value="[mostrar_codigo_descuento]" readonly>
    <button id="copy-shortcode">Copiar</button>
    <span id="copy-tooltip" style="display: none; color: green;">Copiado</span>

    <h2>Códigos Generados</h2>
    <form id="codes-form">
        <table class="wp-list-table widefat fixed striped">
            <thead>
                <tr>
                    <th><input type="checkbox" id="select-all"></th>
                    <th>Código</th>
                    <th>Estado</th>
                    <th>Acción</th>
                </tr>
            </thead>
            <tbody>
                <?php
                // Obtener los códigos generados.
                $codes = get_option('gcd_codes', array());
                foreach ($codes as $index => $code) {
                    ?>
                    <tr>
                        <td><input type="checkbox" class="code-checkbox" data-index="<?php echo esc_attr($index); ?>"></td>
                        <td><?php echo esc_html($code['code']); ?></td>
                        <td><?php echo $code['used'] ? 'Ya utilizado' : 'No usado'; ?></td>
                        <td>
                            <?php if (!$code['used']) : ?>
                                <button type="button" class="mark-used" data-index="<?php echo esc_attr($index); ?>">Marcar como usado</button>
                            <?php else : ?>
                                <span>Usado</span>
                            <?php endif; ?>
                            <button type="button" class="copy-code" data-code="<?php echo esc_attr($code['code']); ?>">Copiar</button>
                            <button type="button" class="delete-code" data-index="<?php echo esc_attr($index); ?>">Eliminar</button>
                        </td>
                    </tr>
                    <?php
                }
                ?>
            </tbody>
        </table>
        <button type="button" id="mark-selected-used">Marcar seleccionados como usados</button>
        <button type="button" id="delete-selected">Eliminar seleccionados</button>
    </form>

    <p>¡Gracias por usar nuestro plugin!</p>
    <p><a href="https://fersosa.com/" target="_blank">Visita el sitio del desarrollador: Fer Sosa</a></p>
</div>

    <?php
}

// Acción AJAX para marcar un código como usado.
add_action('wp_ajax_mark_code_used', 'gcd_mark_code_used');

function gcd_mark_code_used() {
    $index = intval($_POST['index']);
    $codes = get_option('gcd_codes', array());

    if (isset($codes[$index])) {
        $codes[$index]['used'] = true;
        update_option('gcd_codes', $codes);
        wp_send_json_success('Código marcado como usado.');
    } else {
        wp_send_json_error('Error al marcar el código.');
    }
}

// Acción AJAX para eliminar un código.
add_action('wp_ajax_delete_code', 'gcd_delete_code');

function gcd_delete_code() {
    $index = intval($_POST['index']);
    $codes = get_option('gcd_codes', array());

    if (isset($codes[$index])) {
        unset($codes[$index]);
        $codes = array_values($codes); // Re-indexa el array después de eliminar.
        update_option('gcd_codes', $codes);
        wp_send_json_success('Código eliminado.');
    } else {
        wp_send_json_error('Error al eliminar el código.');
    }
}
