<?php
/**
 * Plugin Name: Generador de Códigos de Descuento
 * Description: Plugin para generar códigos de descuento aleatorios y gestionarlos.
 * Version: 1.3.3
 * Author: Fer Sosa
 * Author URI: https://fersosa.com/
 */

// Evita el acceso directo.
if (!defined('ABSPATH')) exit;

// Define rutas y URLs del plugin.
define('GCD_PATH', plugin_dir_path(__FILE__));
define('GCD_URL', plugin_dir_url(__FILE__));

// Incluye archivos necesarios.
require_once GCD_PATH . 'includes/code-generator.php';
require_once GCD_PATH . 'admin/admin-page.php';

// Registra los scripts y estilos.
function gcd_enqueue_scripts() {
    wp_enqueue_style('gcd-style', GCD_URL . 'assets/css/style.css');
    wp_enqueue_script('gcd-script', GCD_URL . 'js/main.js', array('jquery'), null, true);
	wp_enqueue_script('gcd-admin-script', plugin_dir_url(__FILE__) . 'assets/js/admin-script.js', array('jquery'), '1.0', true);
    wp_localize_script('gcd-script', 'gcd_ajax', array('ajax_url' => admin_url('admin-ajax.php')));
}
add_action('wp_enqueue_scripts', 'gcd_enqueue_scripts');

// Registra el shortcode para mostrar el botón de generación de códigos.
function gcd_shortcode() {
    ob_start();
    echo '<button id="generate-code">Mostrar Código de Descuento</button>';
    echo '<div id="generated-code"></div>';
    return ob_get_clean();
}
add_shortcode('mostrar_codigo_descuento', 'gcd_shortcode');

// Acción AJAX para generar el código.
add_action('wp_ajax_generate_code', 'gcd_generate_code');
add_action('wp_ajax_nopriv_generate_code', 'gcd_generate_code');

// Función para generar el código y guardarlo en la base de datos.
function gcd_generate_code() {
    $code = generate_discount_code(); // Función incluida desde includes/code-generator.php
    $codes = get_option('gcd_codes', array());
    $codes[] = array('code' => $code, 'used' => false);
    update_option('gcd_codes', $codes);
    wp_send_json_success($code);
}

// Agrega un enlace de configuración en la página de plugins.
function gcd_plugin_action_links($links) {
    $settings_link = '<a href="admin.php?page=gcd-admin">Configurar y ver códigos</a>';
    array_unshift($links, $settings_link);
    return $links;
}
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'gcd_plugin_action_links');


// Acción AJAX para marcar varios códigos como usados.
add_action('wp_ajax_mark_selected_used', 'gcd_mark_selected_used');
function gcd_mark_selected_used() {
    $indices = isset($_POST['indices']) ? array_map('intval', $_POST['indices']) : array();
    $codes = get_option('gcd_codes', array());

    foreach ($indices as $index) {
        if (isset($codes[$index])) {
            $codes[$index]['used'] = true;
        }
    }

    update_option('gcd_codes', $codes);
    wp_send_json_success();
}

// Acción AJAX para eliminar varios códigos.
add_action('wp_ajax_delete_selected_codes', 'gcd_delete_selected_codes');
function gcd_delete_selected_codes() {
    $indices = isset($_POST['indices']) ? array_map('intval', $_POST['indices']) : array();
    $codes = get_option('gcd_codes', array());

    foreach ($indices as $index) {
        if (isset($codes[$index])) {
            unset($codes[$index]);
        }
    }

    // Reindexar el array de códigos.
    $codes = array_values($codes);

    update_option('gcd_codes', $codes);
    wp_send_json_success();
}
